@@ -5,7 +5,7 @@
  * Authors:
  *      Alvaro Lopez Ortega <alvaro@alobbs.com>
  *
- * Copyright (C) 2001-2009 Alvaro Lopez Ortega
+ * Copyright (C) 2001-2010 Alvaro Lopez Ortega
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -20,7 +20,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  * 02110-1301, USA.
- */ 
+ */
 
 #if !defined (CHEROKEE_INSIDE_CHEROKEE_H) && !defined (CHEROKEE_COMPILATION)
 # error "Only <cherokee/cherokee.h> can be included directly, this file may disappear or change contents."
@@ -34,10 +34,11 @@
 #include <stdarg.h>
 #include <stdlib.h>
 #include <string.h>
-
+#include <limits.h>
 
 CHEROKEE_BEGIN_DECLS
 
+
 typedef struct {
 	char    *buf;        /**< Memory chunk           */
 	cuint_t  size;       /**< Total amount of memory */
@@ -45,7 +46,8 @@ typedef struct {
 } cherokee_buffer_t;
 
 #define BUF(x) ((cherokee_buffer_t *)(x))
-#define CHEROKEE_BUF_INIT      {NULL, 0, 0}
+#define CHEROKEE_BUF_INIT       {NULL, 0, 0}
+#define CHEROKEE_BUF_SLIDE_NONE INT_MIN
 
 #define cherokee_buffer_is_empty(b)        (BUF(b)->len == 0)
 #define cherokee_buffer_add_str(b,s)       cherokee_buffer_add (b, s, CSZLEN(s))
@@ -53,6 +55,7 @@ typedef struct {
 #define cherokee_buffer_prepend_buf(b,s)   cherokee_buffer_prepend (b, (s)->buf, (s)->len)
 #define cherokee_buffer_cmp_str(b,s)       cherokee_buffer_cmp (b, (char *)s, sizeof(s)-1)
 #define cherokee_buffer_case_cmp_str(b,s)  cherokee_buffer_case_cmp (b, (char *)s, sizeof(s)-1)
+#define cherokee_buffer_fake_str(b,s)      cherokee_buffer_fake (b, s, sizeof(s)-1)
 
 ret_t cherokee_buffer_new                (cherokee_buffer_t **buf);
 ret_t cherokee_buffer_free               (cherokee_buffer_t  *buf);
@@ -62,7 +65,7 @@ void  cherokee_buffer_fake               (cherokee_buffer_t  *buf, const char *s
 
 void  cherokee_buffer_clean              (cherokee_buffer_t  *buf);
 ret_t cherokee_buffer_dup                (cherokee_buffer_t  *buf, cherokee_buffer_t **dup);
-void  cherokee_buffer_swap_buffers       (cherokee_buffer_t  *buf, cherokee_buffer_t *second);       
+void  cherokee_buffer_swap_buffers       (cherokee_buffer_t  *buf, cherokee_buffer_t *second);
 
 ret_t cherokee_buffer_add                (cherokee_buffer_t  *buf, const char *txt, size_t size);
 ret_t cherokee_buffer_add_long10         (cherokee_buffer_t  *buf, clong_t lNum);
@@ -77,6 +80,7 @@ ret_t cherokee_buffer_add_va_list        (cherokee_buffer_t  *buf, const char *f
 ret_t cherokee_buffer_add_char           (cherokee_buffer_t  *buf, char c);
 ret_t cherokee_buffer_add_char_n         (cherokee_buffer_t  *buf, char c, int n);
 ret_t cherokee_buffer_add_buffer         (cherokee_buffer_t  *buf, cherokee_buffer_t *buf2);
+ret_t cherokee_buffer_add_buffer_slice   (cherokee_buffer_t  *buf, cherokee_buffer_t *buf2, ssize_t begin, ssize_t end);
 ret_t cherokee_buffer_add_fsize          (cherokee_buffer_t  *buf, CST_OFFSET size);
 ret_t cherokee_buffer_prepend            (cherokee_buffer_t  *buf, const char *txt, size_t size);
 
@@ -98,7 +102,10 @@ ret_t cherokee_buffer_remove_chunk       (cherokee_buffer_t  *buf, cuint_t from,
 ret_t cherokee_buffer_replace_string     (cherokee_buffer_t  *buf, const char *subs, int subs_len, const char *repl, int repl_len);
 ret_t cherokee_buffer_substitute_string  (cherokee_buffer_t  *bufsrc, cherokee_buffer_t *bufdst, char *subs, int subs_len, char *repl, int repl_len);
 ret_t cherokee_buffer_trim               (cherokee_buffer_t  *buf);
+ret_t cherokee_buffer_insert             (cherokee_buffer_t  *buf, char *txt, size_t txt_len, size_t pos);
+ret_t cherokee_buffer_insert_buffer      (cherokee_buffer_t  *buf, cherokee_buffer_t *src, size_t pos);
 
+ret_t cherokee_buffer_get_utf8_len       (cherokee_buffer_t  *buf, cuint_t *len);
 ret_t cherokee_buffer_ensure_addlen      (cherokee_buffer_t  *buf, size_t alen);
 ret_t cherokee_buffer_ensure_size        (cherokee_buffer_t  *buf, size_t size);
 
@@ -113,11 +120,14 @@ ret_t cherokee_buffer_decode_base64      (cherokee_buffer_t  *buf);
 ret_t cherokee_buffer_encode_md5         (cherokee_buffer_t  *buf, cherokee_buffer_t *encoded);
 ret_t cherokee_buffer_encode_md5_digest  (cherokee_buffer_t  *buf);
 ret_t cherokee_buffer_encode_sha1        (cherokee_buffer_t  *buf, cherokee_buffer_t *encoded);
+ret_t cherokee_buffer_encode_sha1_digest (cherokee_buffer_t  *buf);
 ret_t cherokee_buffer_encode_sha1_base64 (cherokee_buffer_t  *buf, cherokee_buffer_t *encoded);
 ret_t cherokee_buffer_encode_hex         (cherokee_buffer_t  *buf, cherokee_buffer_t *encoded);
 ret_t cherokee_buffer_decode_hex         (cherokee_buffer_t  *buf);
 ret_t cherokee_buffer_unescape_uri       (cherokee_buffer_t  *buf);
 ret_t cherokee_buffer_escape_uri         (cherokee_buffer_t  *buf, cherokee_buffer_t *src);
+ret_t cherokee_buffer_escape_uri_delims  (cherokee_buffer_t  *buf, cherokee_buffer_t *src);
+ret_t cherokee_buffer_escape_arg         (cherokee_buffer_t  *buf, cherokee_buffer_t *src);
 ret_t cherokee_buffer_add_escape_html    (cherokee_buffer_t  *buf, cherokee_buffer_t *src);
 ret_t cherokee_buffer_escape_html        (cherokee_buffer_t  *buf, cherokee_buffer_t *src);
 ret_t cherokee_buffer_add_comma_marks    (cherokee_buffer_t  *buf);
